@@ -3,17 +3,33 @@ import numpy as np
 import sys
 from datetime import datetime
 import os
-# import pytesseract
+import pytesseract
+
+cfg = os.path.join("/","lib", "objectdetector", "cfg","yolov4-custom.cfg")
+# print(cfg)
 
 class ObjectDetector:
-    def __init__(self,weights,cfg,classes):
+    def __init__(self, weights, classes, cfg=cfg):
+        
+        if not os.path.exists(weights):
+            weights = os.path.join("/","lib", "objectdetector", "weights", weights) # f"/lib/objectdetector/weights/{weights}"
+    
+            if os.path.exists(weights):
+                print(weights)
+            else:
+                sys.exit("Trained model not found")
+
+            if os.path.exists(cfg):
+                print(cfg)
+            else:
+                sys.exit("{cfg} not exist")
+
+
+
         self.net = cv2.dnn.readNet(weights,cfg)
         self.classes = classes
         self.layer_names = self.net.getLayerNames()
-        try:
-            self.output_layers = [self.layer_names[i[0] - 1] for i in self.net.getUnconnectedOutLayers()]
-        except IndexError:
-            self.output_layers = [self.layer_names[i - 1] for i in self.net.getUnconnectedOutLayers()]
+        self.output_layers = [self.layer_names[i - 1] for i in self.net.getUnconnectedOutLayers()]
         self.colors = np.random.uniform(0, 255, size=(len(classes), 3))
 
     def detect_object(self,img,label=True,detected_only=False):
@@ -73,9 +89,9 @@ class ObjectDetector:
         if not detected_only:
             return self.img
 
-    # def extract_text(self):
-    #     text = pytesseract.image_to_string(self.licence)
-    #     return text.strip()
+    def extract_text(self):
+        text = pytesseract.image_to_string(self.licence)
+        return text.strip()
 
 class ExtractImages:
     def __init__(self,path,op='Output',skip=30):
